@@ -24,9 +24,11 @@ import click
 from click.core import Context
 from click.formatting import HelpFormatter
 
+import osducli
 from osducli.config import CLI_ENV_VAR_PREFIX, CLIConfig
 from osducli.log import get_logger
 from osducli.state import get_default_config
+from osducli.util.pypi import get_pypi_version
 
 
 class State:  # pylint: disable=too-few-public-methods
@@ -80,6 +82,34 @@ class CustomClickGroup(click.Group):
         self.format_commands(ctx, formatter)
 
 
+class CustomMainClickGroup(CustomClickGroup):
+    """Custom click.Group class providing customised help text"""
+
+    def format_help(self, ctx: Context, formatter: HelpFormatter) -> None:
+        """Writes the help into the formatter if it exists.
+
+        This is a low-level method called by :meth:`get_help`.
+
+        This calls the following methods:
+
+        -   :meth:`format_usage`
+        -   :meth:`format_help_text`
+        -   :meth:`format_options`
+        -   :meth:`format_epilog`
+        """
+        super().format_help(ctx, formatter)
+        current_version = osducli.__VERSION__
+        latest_version = get_pypi_version("osducli")
+        if latest_version is not None and current_version != latest_version:
+            formatter.write_paragraph()
+            formatter.write_text(
+                f"\b\n\033[33mWARNING: You are using osdu cli version {current_version}; however version {latest_version} is available.\033[39m"  # noqa: E501 pylint: disable=line-too-long
+            )
+            formatter.write_text(
+                "\b\n\033[33mYou should consider upgrading via the 'pip install -U osdu-cli' command\033[39m"  # noqa: E501 pylint: disable=line-too-long
+            )
+
+
 class CustomClickCommand(click.Command):
     """Custom click.GrouCommand class providing customised help text"""
 
