@@ -13,12 +13,12 @@
 """Custom cluster upgrade specific commands"""
 import click
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 from osducli.config import CONFIG_LEGAL_URL
 
 
-@click.command()
+@click.command(cls=CustomClickCommand)
 @handle_cli_exceptions
 @command_with_output(
     "legalTags[*].{Name:name,Description:description,Classification:properties.securityClassification,PersonalData:properties.personalData,Export:properties.exportClassification,Origin:properties.originator}"  # noqa: E501 pylint: disable=C0301
