@@ -17,6 +17,7 @@ import click
 from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import handle_cli_exceptions
 from osducli.commands.search._const import (
+    SEARCH_DOCUMENTATION,
     SEARCH_SERVICE_NAME,
     SEARCH_STATUS_PATH,
     SEARCH_SWAGGER_PATH,
@@ -32,5 +33,10 @@ from osducli.util.service_info import info
 def _click_command(state: State) -> dict:
     """Information about the service"""
     return info(
-        state, SEARCH_SERVICE_NAME, CONFIG_SEARCH_URL, SEARCH_STATUS_PATH, SEARCH_SWAGGER_PATH
+        state,
+        SEARCH_SERVICE_NAME,
+        CONFIG_SEARCH_URL,
+        SEARCH_STATUS_PATH,
+        SEARCH_SWAGGER_PATH,
+        SEARCH_DOCUMENTATION,
     )
