@@ -21,7 +21,7 @@ from osducli.config import CONFIG_WORKFLOW_URL
 
 # click entry point
 @click.command(cls=CustomClickCommand)
-@click.option("-n", "--name", help="DAG Name", required=True)
+@click.option("-n", "--name", help="Workflow (DAG) name", required=True)
 @handle_cli_exceptions
 @global_params
 def _click_command(state: State, name: str) -> dict:
